<?php

if ( ! isset( $content_width ) )
	$content_width = 745;


/**
 * Calm setup.
 *
 */
function calm_setup() {
	
	load_theme_textdomain( 'calm', get_template_directory() . '/lang' );

	

	// Adds RSS feed links to <head> for posts and comments.
	add_theme_support( 'automatic-feed-links' );

	/*
	 * Switches default core markup for search form, comment form,
	 * and comments to output valid HTML5.
	 */
	add_theme_support( 'html5', array( 'search-form', 'comment-form', 'comment-list' ) );

	/*
	 * This theme supports all available post formats by default.
	 * See http://codex.wordpress.org/Post_Formats
	 */
	add_theme_support( 'post-formats', array(
		'aside', 'audio', 'quote', 'video', 'link'
	) );

	/* Custom Header */
	add_theme_support('custom-header',array(
		
		'height' => 450,
		'width' => 1920,
		'flex-width' => true,
		'flex-height' => false,
		'header-text' => false,
		'random-default' => false

		));

	// This theme uses wp_nav_menu() in one location.
	register_nav_menus(array(
		'top-menu' => __( 'Top Menu', 'calm' ),
		'mobile-menu' => __('Mobile Top Menu', 'calm'),
		'footer-menu' => __('Footer Menu', 'calm')
		));


	/*
	 * This theme uses a custom image size for featured images, displayed on
	 * "standard" posts and pages.
	 */
	add_theme_support( 'post-thumbnails' );
	set_post_thumbnail_size( 220, 340, true );
	add_image_size( 'image',770, 335, true );


	
}
add_action( 'after_setup_theme', 'calm_setup' );



function calm_scripts_styles() {
	/*
	 * Adds JavaScript to pages with the comment form to support
	 * sites with threaded comments (when in use).
	 */
	if ( is_singular() && comments_open() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );


	
	wp_enqueue_script('calm-custom',get_template_directory_uri().'/js/calm-custom.js',array('jquery'),'',true);

	wp_enqueue_script('smoothScroll',get_template_directory_uri().'/js/SmoothScroll.js',array('jquery'),'',true);

		


	// Add fonts, icons used in the main stylesheet.
	wp_enqueue_style( 'font-awesome', get_template_directory_uri() . '/css/font-awesome.css', array(), '' );
	wp_enqueue_style( 'bootstrap-theme', get_template_directory_uri() . '/css/bootstrap-theme.css', array(), '' );
	wp_enqueue_style( 'bootstrap', get_template_directory_uri() . '/css/bootstrap.css', array(), '' );
	

	// Loads our main stylesheet.
	wp_enqueue_style( 'calm-style', get_stylesheet_uri(), array(), '' );

	
}
add_action( 'wp_enqueue_scripts', 'calm_scripts_styles' );




function calm_wp_title( $title, $sep ) {
	global $paged, $page;

	if ( is_feed() )
		return $title;

	// Add the site name.
	$title .= get_bloginfo( 'name' );

	// Add the site description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		$title = "$title $sep $site_description";

	// Add a page number if necessary.
	if ( $paged >= 2 || $page >= 2 )
		$title = "$title $sep " . sprintf( __( 'Page %s', 'Calm' ), max( $paged, $page ) );

	return $title;
}
add_filter( 'wp_title', 'calm_wp_title', 10, 2 );





/* Excerpt Filter */
function calm_excerpt_length( $length ) {
	return 110;
}
add_filter( 'excerpt_length', 'calm_excerpt_length', 999 );



/* Excerpt More */
function new_excerpt_more( $more ) {
	return ' .....';
}
add_filter('excerpt_more', 'new_excerpt_more');





function calm_widgets(){

	/* Dynamic Sidebar */
register_sidebar(array(
	'id'          => 'sidebar',
    'name'        => __( 'Right Sidebar', 'calm' ),
    'description' => __( 'This sidebar is located right side.', 'calm' ),
    'before_widget' => '<div class="widget">',
	'after_widget'  => '</div>',
	'before_title'  => '<h3>',
	'after_title'   => '</h3>',
	));



/* Footer Widget 1 */
register_sidebar(array(
	'id'          => 'footer-1',
    'name'        => __( 'Left Footer Widget', 'calm' ),
    'description' => __( 'This widget is located left side.', 'calm' ),
    'before_widget' => '<div class="col-sm-4 footer-widget">',
	'after_widget'  => '</div>',
	'before_title'  => '<h3>',
	'after_title'   => '</h3>',
	));




/* Footer Widget 2 */
register_sidebar(array(
	'id'          => 'footer-2',
    'name'        => __( 'Right Footer Widget', 'calm' ),
    'description' => __( 'This widget is located right side.', 'calm' ),
    'before_widget' => '<div class="col-sm-4 footer-widget">',
	'after_widget'  => '</div>',
	'before_title'  => '<h3>',
	'after_title'   => '</h3>',
	));



/* Footer Widget 3 */
register_sidebar(array(
	'id'          => 'footer-3',
    'name'        => __( 'Middle Footer Widget', 'calm' ),
    'description' => __( 'This widget is located center side.', 'calm' ),
    'before_widget' => '<div class="col-sm-4 footer-widget">',
	'after_widget'  => '</div>',
	'before_title'  => '<h3>',
	'after_title'   => '</h3>',
	));

}
add_action('widgets_init', 'calm_widgets');





/* Paging */
function calm_paging_nav() {
	global $wp_query;

	// Don't print empty markup if there's only one page.
	if ( $wp_query->max_num_pages < 2 )
		return;
	?>
	<div class="pagination clearfix" role="navigation">

			<?php if ( get_next_posts_link() ) : ?>
			<div class="older-posts pull-left"><?php next_posts_link('<i class="fa fa-angle-left fa-2x"></i>'); ?></div>
			<?php endif; ?>

			

			<?php if ( get_previous_posts_link() ) : ?>
			<div class="newer-posts pull-right"><?php previous_posts_link('<i class="fa fa-angle-right fa-2x"></i>'); ?></div>
			<?php endif; ?>
		
	</div><!-- end pagination -->
	<?php
}






/***********************************************************************************************/
/* Custom Comment Form */
/***********************************************************************************************/
function calm_custom_comment_form($defaults) {
	
	
	$defaults['comment_notes_before'] = '';
	
	$defaults['id_form'] = 'comment-form';
	$defaults['comment_field'] = '<p><textarea name="comment" id="comment" class="form-control input-lg" rows="6"></textarea></p>';

	return $defaults;
}

add_filter('comment_form_defaults', 'calm_custom_comment_form');

function calm_custom_comment_fields() {
	$commenter = wp_get_current_commenter();
	$req = get_option('require_name_email');
	$aria_req = ($req ? " aria-required='true'" : '');
	
	$fields = array(
		'author' => '<p>' . 
						'<input id="author" name="author" type="text" class="form-control" placeholder="Name ( required )" value="' . esc_attr($commenter['comment_author']) . '" ' . $aria_req . ' />' .
						
		            '</p>',
		'email' => '<p>' . 
						'<input id="email" name="email" type="text" class="form-control" placeholder="Email ( required )" value="' . esc_attr($commenter['comment_author_email']) . '" ' . $aria_req . ' />'  .
		            '</p>',
		'url' => '<p>' . 
						'<input id="url" name="url" type="text" class="form-control" placeholder="Website" value="' . esc_attr($commenter['comment_author_url']) . '" />'  .
		            '</p>'
	);

	return $fields;
}

add_filter('comment_form_default_fields', 'calm_custom_comment_fields');